@@ -2,22 +2,9 @@
 
 
 from __future__ import annotations
-from abc import abstractmethod
-from math import inf, floor, ceil
-from typing import Optional, Tuple, Generic, TypeVar, Protocol, Union
+from typing import Generic, TypeVar
 from dataclasses import dataclass
 
-# @dataclass
-# class SocketUpdate:
-#     def __init__(self,val):
-#         self.val=val
-
-#     def a_fxn(self):
-#         print('This is a function')
-
-#     def __repr__(self):
-#         return str(self.val)
-
 T = TypeVar("T")
 
 @dataclass
@@ -29,7 +16,7 @@ class CircularBufferNode(Generic[T]):
         return repr(self.data)
 
 @dataclass
-class CircularBuffer:
+class CircularBuffer(Generic[T]):
     capacity : int
     curr_size : int = 0
     oldest : CircularBufferNode[T] = None
@@ -61,12 +48,6 @@ class CircularBuffer:
     def __str__(self):
         return ', '.join([str(node) for node in self])
 
-# class Trader:
-#     prices : CircularBuffer[SocketUpdate]
-
-#     def __init__(self):
-#         self.prices = CircularBuffer(capacity=3)
-
 
 
 
